==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/wsdl/model/ObjectFactory.java <==

package org.somda.sdc.dpws.wsdl.model;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.somda.sdc.dpws.wsdl.model package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Definitions_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "definitions");
    private final static QName _TOperationInput_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "input");
    private final static QName _TOperationOutput_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "output");
    private final static QName _TOperationFault_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "fault");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.somda.sdc.dpws.wsdl.model
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TDefinitions }
     * 
     */
    public TDefinitions createTDefinitions() {
        return new TDefinitions();
    }

    /**
     * Create an instance of {@link TDocumentation }
     * 
     */
    public TDocumentation createTDocumentation() {
        return new TDocumentation();
    }

    /**
     * Create an instance of {@link TDocumented }
     * 
     */
    public TDocumented createTDocumented() {
        return new TDocumented();
    }

    /**
     * Create an instance of {@link TImport }
     * 
     */
    public TImport createTImport() {
        return new TImport();
    }

    /**
     * Create an instance of {@link TTypes }
     * 
     */
    public TTypes createTTypes() {
        return new TTypes();
    }

    /**
     * Create an instance of {@link TMessage }
     * 
     */
    public TMessage createTMessage() {
        return new TMessage();
    }

    /**
     * Create an instance of {@link TPart }
     * 
     */
    public TPart createTPart() {
        return new TPart();
    }

    /**
     * Create an instance of {@link TPortType }
     * 
     */
    public TPortType createTPortType() {
        return new TPortType();
    }

    /**
     * Create an instance of {@link TOperation }
     * 
     */
    public TOperation createTOperation() {
        return new TOperation();
    }

    /**
     * Create an instance of {@link TParam }
     * 
     */
    public TParam createTParam() {
        return new TParam();
    }

    /**
     * Create an instance of {@link TFault }
     * 
     */
    public TFault createTFault() {
        return new TFault();
    }

    /**
     * Create an instance of {@link TBinding }
     * 
     */
    public TBinding createTBinding() {
        return new TBinding();
    }

    /**
     * Create an instance of {@link TBindingOperationMessage }
     * 
     */
    public TBindingOperationMessage createTBindingOperationMessage() {
        return new TBindingOperationMessage();
    }

    /**
     * Create an instance of {@link TBindingOperationFault }
     * 
     */
    public TBindingOperationFault createTBindingOperationFault() {
        return new TBindingOperationFault();
    }

    /**
     * Create an instance of {@link TBindingOperation }
     * 
     */
    public TBindingOperation createTBindingOperation() {
        return new TBindingOperation();
    }

    /**
     * Create an instance of {@link TService }
     * 
     */
    public TService createTService() {
        return new TService();
    }

    /**
     * Create an instance of {@link TPort }
     * 
     */
    public TPort createTPort() {
        return new TPort();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TDefinitions }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TDefinitions }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "definitions")
    public JAXBElement<TDefinitions> createDefinitions(TDefinitions value) {
        return new JAXBElement<TDefinitions>(_Definitions_QNAME, TDefinitions.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "input", scope = TOperation.class)
    public JAXBElement<TParam> createTOperationInput(TParam value) {
        return new JAXBElement<TParam>(_TOperationInput_QNAME, TParam.class, TOperation.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "output", scope = TOperation.class)
    public JAXBElement<TParam> createTOperationOutput(TParam value) {
        return new JAXBElement<TParam>(_TOperationOutput_QNAME, TParam.class, TOperation.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TFault }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TFault }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "fault", scope = TOperation.class)
    public JAXBElement<TFault> createTOperationFault(TFault value) {
        return new JAXBElement<TFault>(_TOperationFault_QNAME, TFault.class, TOperation.class, value);
    }

}

==> dpws-model-6.0.0-sources.jar: org/somda/sdc/dpws/wsdl/model/ObjectFactory.java <==

package org.somda.sdc.dpws.wsdl.model;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.somda.sdc.dpws.wsdl.model package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _Definitions_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "definitions");
    private static final QName _TOperationInput_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "input");
    private static final QName _TOperationOutput_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "output");
    private static final QName _TOperationFault_QNAME = new QName("http://schemas.xmlsoap.org/wsdl/", "fault");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.somda.sdc.dpws.wsdl.model
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TDefinitions }
     * 
     * @return
     *     the new instance of {@link TDefinitions }
     */
    public TDefinitions createTDefinitions() {
        return new TDefinitions();
    }

    /**
     * Create an instance of {@link TDocumentation }
     * 
     * @return
     *     the new instance of {@link TDocumentation }
     */
    public TDocumentation createTDocumentation() {
        return new TDocumentation();
    }

    /**
     * Create an instance of {@link TDocumented }
     * 
     * @return
     *     the new instance of {@link TDocumented }
     */
    public TDocumented createTDocumented() {
        return new TDocumented();
    }

    /**
     * Create an instance of {@link TImport }
     * 
     * @return
     *     the new instance of {@link TImport }
     */
    public TImport createTImport() {
        return new TImport();
    }

    /**
     * Create an instance of {@link TTypes }
     * 
     * @return
     *     the new instance of {@link TTypes }
     */
    public TTypes createTTypes() {
        return new TTypes();
    }

    /**
     * Create an instance of {@link TMessage }
     * 
     * @return
     *     the new instance of {@link TMessage }
     */
    public TMessage createTMessage() {
        return new TMessage();
    }

    /**
     * Create an instance of {@link TPart }
     * 
     * @return
     *     the new instance of {@link TPart }
     */
    public TPart createTPart() {
        return new TPart();
    }

    /**
     * Create an instance of {@link TPortType }
     * 
     * @return
     *     the new instance of {@link TPortType }
     */
    public TPortType createTPortType() {
        return new TPortType();
    }

    /**
     * Create an instance of {@link TOperation }
     * 
     * @return
     *     the new instance of {@link TOperation }
     */
    public TOperation createTOperation() {
        return new TOperation();
    }

    /**
     * Create an instance of {@link TParam }
     * 
     * @return
     *     the new instance of {@link TParam }
     */
    public TParam createTParam() {
        return new TParam();
    }

    /**
     * Create an instance of {@link TFault }
     * 
     * @return
     *     the new instance of {@link TFault }
     */
    public TFault createTFault() {
        return new TFault();
    }

    /**
     * Create an instance of {@link TBinding }
     * 
     * @return
     *     the new instance of {@link TBinding }
     */
    public TBinding createTBinding() {
        return new TBinding();
    }

    /**
     * Create an instance of {@link TBindingOperationMessage }
     * 
     * @return
     *     the new instance of {@link TBindingOperationMessage }
     */
    public TBindingOperationMessage createTBindingOperationMessage() {
        return new TBindingOperationMessage();
    }

    /**
     * Create an instance of {@link TBindingOperationFault }
     * 
     * @return
     *     the new instance of {@link TBindingOperationFault }
     */
    public TBindingOperationFault createTBindingOperationFault() {
        return new TBindingOperationFault();
    }

    /**
     * Create an instance of {@link TBindingOperation }
     * 
     * @return
     *     the new instance of {@link TBindingOperation }
     */
    public TBindingOperation createTBindingOperation() {
        return new TBindingOperation();
    }

    /**
     * Create an instance of {@link TService }
     * 
     * @return
     *     the new instance of {@link TService }
     */
    public TService createTService() {
        return new TService();
    }

    /**
     * Create an instance of {@link TPort }
     * 
     * @return
     *     the new instance of {@link TPort }
     */
    public TPort createTPort() {
        return new TPort();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TDefinitions }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TDefinitions }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "definitions")
    public JAXBElement<TDefinitions> createDefinitions(TDefinitions value) {
        return new JAXBElement<>(_Definitions_QNAME, TDefinitions.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "input", scope = TOperation.class)
    public JAXBElement<TParam> createTOperationInput(TParam value) {
        return new JAXBElement<>(_TOperationInput_QNAME, TParam.class, TOperation.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TParam }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "output", scope = TOperation.class)
    public JAXBElement<TParam> createTOperationOutput(TParam value) {
        return new JAXBElement<>(_TOperationOutput_QNAME, TParam.class, TOperation.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TFault }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link TFault }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.xmlsoap.org/wsdl/", name = "fault", scope = TOperation.class)
    public JAXBElement<TFault> createTOperationFault(TFault value) {
        return new JAXBElement<>(_TOperationFault_QNAME, TFault.class, TOperation.class, value);
    }

}
